@@ -12,14 +12,13 @@ import asyncio
 import time
 from typing import TYPE_CHECKING, Any, Dict, Iterator, List, Optional, cast
 
-from xknx.remote_value import RemoteValueSwitch
+from xknx.remote_value import GroupAddressesType, RemoteValueSwitch
 
 from .action import Action
 from .device import Device, DeviceCallbackType
 
 if TYPE_CHECKING:
     from xknx.telegram import Telegram
-    from xknx.telegram.address import GroupAddressableType
     from xknx.xknx import XKNX
 
 
@@ -31,7 +30,7 @@ class BinarySensor(Device):
         self,
         xknx: "XKNX",
         name: str,
-        group_address_state: "GroupAddressableType" = None,
+        group_address_state: GroupAddressesType = None,
         invert: bool = False,
         sync_state: bool = True,
         ignore_internal_state: bool = False,
@@ -120,7 +119,8 @@ class BinarySensor(Device):
 
     async def _state_from_remote_value(self) -> None:
         """Update the internal state from RemoteValue (Callback)."""
-        await self._set_internal_state(self.remote_value.value)
+        if self.remote_value.value is not None:
+            await self._set_internal_state(self.remote_value.value)
 
     async def _set_internal_state(self, state: bool) -> None:
         """Set the internal state of the device. If state was changed after_update hooks and connected Actions are executed."""
