@@ -6,9 +6,11 @@ Module for managing the climate within a room.
 """
 from enum import Enum
 import logging
-from typing import TYPE_CHECKING, Any, Dict, Iterator, Optional, Union, cast
+from typing import TYPE_CHECKING, Any, Dict, Iterator, Optional, Union
 
 from xknx.remote_value import (
+    GroupAddressesType,
+    RemoteValue,
     RemoteValueSetpointShift,
     RemoteValueSwitch,
     RemoteValueTemp,
@@ -19,9 +21,8 @@ from .device import Device, DeviceCallbackType
 from .sensor import Sensor
 
 if TYPE_CHECKING:
-    from xknx.remote_value import RemoteValue
     from xknx.telegram import Telegram
-    from xknx.telegram.address import GroupAddress, GroupAddressableType
+    from xknx.telegram.address import GroupAddress
     from xknx.xknx import XKNX
 
 logger = logging.getLogger("xknx.log")
@@ -48,17 +49,17 @@ class Climate(Device):
         self,
         xknx: "XKNX",
         name: str,
-        group_address_temperature: Optional["GroupAddressableType"] = None,
-        group_address_target_temperature: Optional["GroupAddressableType"] = None,
-        group_address_target_temperature_state: Optional["GroupAddressableType"] = None,
-        group_address_setpoint_shift: Optional["GroupAddressableType"] = None,
-        group_address_setpoint_shift_state: Optional["GroupAddressableType"] = None,
+        group_address_temperature: Optional[GroupAddressesType] = None,
+        group_address_target_temperature: Optional[GroupAddressesType] = None,
+        group_address_target_temperature_state: Optional[GroupAddressesType] = None,
+        group_address_setpoint_shift: Optional[GroupAddressesType] = None,
+        group_address_setpoint_shift_state: Optional[GroupAddressesType] = None,
         setpoint_shift_mode: SetpointShiftMode = DEFAULT_SETPOINT_SHIFT_MODE,
         setpoint_shift_max: float = DEFAULT_SETPOINT_SHIFT_MAX,
         setpoint_shift_min: float = DEFAULT_SETPOINT_SHIFT_MIN,
         temperature_step: float = DEFAULT_TEMPERATURE_STEP,
-        group_address_on_off: Optional["GroupAddressableType"] = None,
-        group_address_on_off_state: Optional["GroupAddressableType"] = None,
+        group_address_on_off: Optional[GroupAddressesType] = None,
+        group_address_on_off_state: Optional[GroupAddressesType] = None,
         on_off_invert: bool = False,
         min_temp: Optional[float] = None,
         max_temp: Optional[float] = None,
@@ -130,7 +131,7 @@ class Climate(Device):
         if create_temperature_sensors:
             self.create_temperature_sensors()
 
-    def _iter_remote_values(self) -> Iterator["RemoteValue[Any]"]:
+    def _iter_remote_values(self) -> Iterator[RemoteValue[Any, Any]]:
         """Iterate the devices RemoteValue classes."""
         yield from (
             self.temperature,
@@ -241,15 +242,14 @@ class Climate(Device):
     @property
     def initialized_for_setpoint_shift_calculations(self) -> bool:
         """Test if object is initialized for setpoint shift calculations."""
-        if not self._setpoint_shift.initialized:
-            return False
-        if self._setpoint_shift.value is None:
-            return False
-        if not self.target_temperature.initialized:
-            return False
-        if self.target_temperature.value is None:
-            return False
-        return True
+        if (
+            self._setpoint_shift.initialized
+            and self._setpoint_shift.value is not None
+            and self.target_temperature.initialized
+            and self.target_temperature.value is not None
+        ):
+            return True
+        return False
 
     async def set_target_temperature(self, target_temperature: float) -> None:
         """Send new target temperature or setpoint_shift to KNX bus."""
@@ -272,14 +272,18 @@ class Climate(Device):
         As this value is usually not available via KNX, we have to derive this from the current
         target temperature and the current set point shift.
         """
-        if self.initialized_for_setpoint_shift_calculations:
-            return cast(float, self.target_temperature.value - self.setpoint_shift)
+        # implies self.initialized_for_setpoint_shift_calculations in a mypy compatible way:
+        if (
+            self.target_temperature.value is not None
+            and self._setpoint_shift.value is not None
+        ):
+            return self.target_temperature.value - self._setpoint_shift.value
         return None
 
     @property
     def setpoint_shift(self) -> Optional[float]:
         """Return current offset from base temperature in Kelvin."""
-        return self._setpoint_shift.value  # type: ignore
+        return self._setpoint_shift.value
 
     def validate_value(
         self, value: float, min_value: Optional[float], max_value: Optional[float]
