@@ -19,12 +19,14 @@ from typing import (
     Callable,
     Dict,
     Iterator,
-    List,
     Optional,
     Tuple,
+    cast,
 )
 
 from xknx.remote_value import (
+    GroupAddressesType,
+    RemoteValue,
     RemoteValueColorRGB,
     RemoteValueColorRGBW,
     RemoteValueDpt2ByteUnsigned,
@@ -35,9 +37,7 @@ from xknx.remote_value import (
 from .device import Device, DeviceCallbackType
 
 if TYPE_CHECKING:
-    from xknx.remote_value import RemoteValue
     from xknx.telegram import Telegram
-    from xknx.telegram.address import GroupAddressableType
     from xknx.xknx import XKNX
 
 AsyncCallback = Callable[[], Awaitable[None]]
@@ -58,10 +58,10 @@ class _SwitchAndBrightness:
         xknx: "XKNX",
         name: str,
         feature_name: str,
-        group_address_switch: Optional["GroupAddressableType"] = None,
-        group_address_switch_state: Optional["GroupAddressableType"] = None,
-        group_address_brightness: Optional["GroupAddressableType"] = None,
-        group_address_brightness_state: Optional["GroupAddressableType"] = None,
+        group_address_switch: Optional[GroupAddressesType] = None,
+        group_address_switch_state: Optional[GroupAddressesType] = None,
+        group_address_brightness: Optional[GroupAddressesType] = None,
+        group_address_brightness_state: Optional[GroupAddressesType] = None,
         after_update_cb: Optional[AsyncCallback] = None,
     ):
         self.switch = RemoteValueSwitch(
@@ -86,7 +86,7 @@ class _SwitchAndBrightness:
     @property
     def is_on(self) -> Optional[bool]:
         """Return if light is on."""
-        return self.switch.value  # type: ignore
+        return self.switch.value
 
     async def set_on(self) -> None:
         """Switch light on."""
@@ -115,34 +115,34 @@ class Light(Device):
         self,
         xknx: "XKNX",
         name: str,
-        group_address_switch: Optional["GroupAddressableType"] = None,
-        group_address_switch_state: Optional["GroupAddressableType"] = None,
-        group_address_brightness: Optional["GroupAddressableType"] = None,
-        group_address_brightness_state: Optional["GroupAddressableType"] = None,
-        group_address_color: Optional["GroupAddressableType"] = None,
-        group_address_color_state: Optional["GroupAddressableType"] = None,
-        group_address_rgbw: Optional["GroupAddressableType"] = None,
-        group_address_rgbw_state: Optional["GroupAddressableType"] = None,
-        group_address_tunable_white: Optional["GroupAddressableType"] = None,
-        group_address_tunable_white_state: Optional["GroupAddressableType"] = None,
-        group_address_color_temperature: Optional["GroupAddressableType"] = None,
-        group_address_color_temperature_state: Optional["GroupAddressableType"] = None,
-        group_address_switch_red: Optional["GroupAddressableType"] = None,
-        group_address_switch_red_state: Optional["GroupAddressableType"] = None,
-        group_address_brightness_red: Optional["GroupAddressableType"] = None,
-        group_address_brightness_red_state: Optional["GroupAddressableType"] = None,
-        group_address_switch_green: Optional["GroupAddressableType"] = None,
-        group_address_switch_green_state: Optional["GroupAddressableType"] = None,
-        group_address_brightness_green: Optional["GroupAddressableType"] = None,
-        group_address_brightness_green_state: Optional["GroupAddressableType"] = None,
-        group_address_switch_blue: Optional["GroupAddressableType"] = None,
-        group_address_switch_blue_state: Optional["GroupAddressableType"] = None,
-        group_address_brightness_blue: Optional["GroupAddressableType"] = None,
-        group_address_brightness_blue_state: Optional["GroupAddressableType"] = None,
-        group_address_switch_white: Optional["GroupAddressableType"] = None,
-        group_address_switch_white_state: Optional["GroupAddressableType"] = None,
-        group_address_brightness_white: Optional["GroupAddressableType"] = None,
-        group_address_brightness_white_state: Optional["GroupAddressableType"] = None,
+        group_address_switch: Optional[GroupAddressesType] = None,
+        group_address_switch_state: Optional[GroupAddressesType] = None,
+        group_address_brightness: Optional[GroupAddressesType] = None,
+        group_address_brightness_state: Optional[GroupAddressesType] = None,
+        group_address_color: Optional[GroupAddressesType] = None,
+        group_address_color_state: Optional[GroupAddressesType] = None,
+        group_address_rgbw: Optional[GroupAddressesType] = None,
+        group_address_rgbw_state: Optional[GroupAddressesType] = None,
+        group_address_tunable_white: Optional[GroupAddressesType] = None,
+        group_address_tunable_white_state: Optional[GroupAddressesType] = None,
+        group_address_color_temperature: Optional[GroupAddressesType] = None,
+        group_address_color_temperature_state: Optional[GroupAddressesType] = None,
+        group_address_switch_red: Optional[GroupAddressesType] = None,
+        group_address_switch_red_state: Optional[GroupAddressesType] = None,
+        group_address_brightness_red: Optional[GroupAddressesType] = None,
+        group_address_brightness_red_state: Optional[GroupAddressesType] = None,
+        group_address_switch_green: Optional[GroupAddressesType] = None,
+        group_address_switch_green_state: Optional[GroupAddressesType] = None,
+        group_address_brightness_green: Optional[GroupAddressesType] = None,
+        group_address_brightness_green_state: Optional[GroupAddressesType] = None,
+        group_address_switch_blue: Optional[GroupAddressesType] = None,
+        group_address_switch_blue_state: Optional[GroupAddressesType] = None,
+        group_address_brightness_blue: Optional[GroupAddressesType] = None,
+        group_address_brightness_blue_state: Optional[GroupAddressesType] = None,
+        group_address_switch_white: Optional[GroupAddressesType] = None,
+        group_address_switch_white_state: Optional[GroupAddressesType] = None,
+        group_address_brightness_white: Optional[GroupAddressesType] = None,
+        group_address_brightness_white_state: Optional[GroupAddressesType] = None,
         min_kelvin: Optional[int] = None,
         max_kelvin: Optional[int] = None,
         device_updated_cb: Optional[DeviceCallbackType] = None,
@@ -254,7 +254,7 @@ class Light(Device):
         self.min_kelvin = min_kelvin
         self.max_kelvin = max_kelvin
 
-    def _iter_remote_values(self) -> Iterator["RemoteValue[Any]"]:
+    def _iter_remote_values(self) -> Iterator[RemoteValue[Any, Any]]:
         """Iterate the devices RemoteValue classes."""
         yield self.switch
         yield self.brightness
@@ -303,10 +303,10 @@ class Light(Device):
     def read_color_from_config(
         cls, color: str, config: Any
     ) -> Tuple[
-        Optional["GroupAddressableType"],
-        Optional["GroupAddressableType"],
-        Optional["GroupAddressableType"],
-        Optional["GroupAddressableType"],
+        Optional[GroupAddressesType],
+        Optional[GroupAddressesType],
+        Optional[GroupAddressesType],
+        Optional[GroupAddressesType],
     ]:
         """Load color configuration from configuration structure."""
         if "individual_colors" in config and color in config["individual_colors"]:
@@ -497,7 +497,7 @@ class Light(Device):
     def state(self) -> Optional[bool]:
         """Return the current switch state of the device."""
         if self.switch.value is not None:
-            return self.switch.value  # type: ignore
+            return self.switch.value
         if any(c.switch.value is not None for c in self._iter_individual_colors()):
             return any(c.switch.value for c in self._iter_individual_colors())
         return None
@@ -519,7 +519,7 @@ class Light(Device):
     @property
     def current_brightness(self) -> Optional[int]:
         """Return current brightness of light."""
-        return self.brightness.value  # type: ignore
+        return self.brightness.value
 
     async def set_brightness(self, brightness: int) -> None:
         """Set brightness of light."""
@@ -550,9 +550,11 @@ class Light(Device):
         )
         if None in colors:
             return None, self.white.brightness.value
-        return colors, self.white.brightness.value
+        return cast(Tuple[int, int, int], colors), self.white.brightness.value
 
-    async def set_color(self, color: List[int], white: Optional[int] = None) -> None:
+    async def set_color(
+        self, color: Tuple[int, int, int], white: Optional[int] = None
+    ) -> None:
         """
         Set color of a light device.
 
@@ -590,7 +592,7 @@ class Light(Device):
     @property
     def current_tunable_white(self) -> Optional[int]:
         """Return current relative color temperature of light."""
-        return self.tunable_white.value  # type: ignore
+        return self.tunable_white.value
 
     async def set_tunable_white(self, tunable_white: int) -> None:
         """Set relative color temperature of light."""
@@ -602,7 +604,7 @@ class Light(Device):
     @property
     def current_color_temperature(self) -> Optional[int]:
         """Return current absolute color temperature of light."""
-        return self.color_temperature.value  # type: ignore
+        return self.color_temperature.value
 
     async def set_color_temperature(self, color_temperature: int) -> None:
         """Set absolute color temperature of light."""
