@@ -16,14 +16,18 @@ from datetime import date, datetime
 from enum import Enum
 from typing import TYPE_CHECKING, Any, Callable, Dict, Iterator, Optional, Tuple
 
-from xknx.remote_value import RemoteValue, RemoteValueSensor, RemoteValueSwitch
+from xknx.remote_value import (
+    GroupAddressesType,
+    RemoteValue,
+    RemoteValueSensor,
+    RemoteValueSwitch,
+)
 
 from . import BinarySensor, Sensor
 from .device import Device, DeviceCallbackType
 
 if TYPE_CHECKING:
     from xknx.telegram import Telegram
-    from xknx.telegram.address import GroupAddressableType
     from xknx.xknx import XKNX
 
 
@@ -81,19 +85,19 @@ class Weather(Device):
         self,
         xknx: "XKNX",
         name: str,
-        group_address_temperature: Optional["GroupAddressableType"] = None,
-        group_address_brightness_south: Optional["GroupAddressableType"] = None,
-        group_address_brightness_north: Optional["GroupAddressableType"] = None,
-        group_address_brightness_west: Optional["GroupAddressableType"] = None,
-        group_address_brightness_east: Optional["GroupAddressableType"] = None,
-        group_address_wind_speed: Optional["GroupAddressableType"] = None,
-        group_address_wind_bearing: Optional["GroupAddressableType"] = None,
-        group_address_rain_alarm: Optional["GroupAddressableType"] = None,
-        group_address_frost_alarm: Optional["GroupAddressableType"] = None,
-        group_address_wind_alarm: Optional["GroupAddressableType"] = None,
-        group_address_day_night: Optional["GroupAddressableType"] = None,
-        group_address_air_pressure: Optional["GroupAddressableType"] = None,
-        group_address_humidity: Optional["GroupAddressableType"] = None,
+        group_address_temperature: Optional[GroupAddressesType] = None,
+        group_address_brightness_south: Optional[GroupAddressesType] = None,
+        group_address_brightness_north: Optional[GroupAddressesType] = None,
+        group_address_brightness_west: Optional[GroupAddressesType] = None,
+        group_address_brightness_east: Optional[GroupAddressesType] = None,
+        group_address_wind_speed: Optional[GroupAddressesType] = None,
+        group_address_wind_bearing: Optional[GroupAddressesType] = None,
+        group_address_rain_alarm: Optional[GroupAddressesType] = None,
+        group_address_frost_alarm: Optional[GroupAddressesType] = None,
+        group_address_wind_alarm: Optional[GroupAddressesType] = None,
+        group_address_day_night: Optional[GroupAddressesType] = None,
+        group_address_air_pressure: Optional[GroupAddressesType] = None,
+        group_address_humidity: Optional[GroupAddressesType] = None,
         create_sensors: bool = False,
         sync_state: bool = True,
         device_updated_cb: Optional[DeviceCallbackType] = None,
@@ -227,7 +231,7 @@ class Weather(Device):
         if create_sensors:
             self.create_sensors()
 
-    def _iter_remote_values(self) -> Iterator[RemoteValue[Any]]:
+    def _iter_remote_values(self) -> Iterator[RemoteValue[Any, Any]]:
         """Iterate the devices remote values."""
         yield self._temperature
         yield self._brightness_south
@@ -256,34 +260,30 @@ class Weather(Device):
     @property
     def brightness_south(self) -> float:
         """Return brightness south."""
-        return (  # type: ignore
-            0.0
-            if self._brightness_south.value is None
-            else self._brightness_south.value
-        )
+        if self._brightness_south.value is not None:
+            return self._brightness_south.value  # type: ignore
+        return 0.0
 
     @property
     def brightness_north(self) -> float:
         """Return brightness north."""
-        return (  # type: ignore
-            0.0
-            if self._brightness_north.value is None
-            else self._brightness_north.value
-        )
+        if self._brightness_north.value is not None:
+            return self._brightness_north.value  # type: ignore
+        return 0.0
 
     @property
     def brightness_east(self) -> float:
         """Return brightness east."""
-        return (  # type: ignore
-            0.0 if self._brightness_east.value is None else self._brightness_east.value
-        )
+        if self._brightness_east.value is not None:
+            return self._brightness_east.value  # type: ignore
+        return 0.0
 
     @property
     def brightness_west(self) -> float:
         """Return brightness west."""
-        return (  # type: ignore
-            0.0 if self._brightness_west.value is None else self._brightness_west.value
-        )
+        if self._brightness_west.value is not None:
+            return self._brightness_west.value  # type: ignore
+        return 0.0
 
     @property
     def wind_speed(self) -> Optional[float]:
@@ -298,22 +298,22 @@ class Weather(Device):
     @property
     def rain_alarm(self) -> Optional[bool]:
         """Return True if rain alarm False if not."""
-        return self._rain_alarm.value  # type: ignore
+        return self._rain_alarm.value
 
     @property
     def wind_alarm(self) -> Optional[bool]:
         """Return True if wind alarm False if not."""
-        return self._wind_alarm.value  # type: ignore
+        return self._wind_alarm.value
 
     @property
     def frost_alarm(self) -> Optional[bool]:
         """Return True if frost alarm False if not."""
-        return self._frost_alarm.value  # type: ignore
+        return self._frost_alarm.value
 
     @property
     def day_night(self) -> Optional[bool]:
         """Return day or night."""
-        return self._day_night.value  # type: ignore
+        return self._day_night.value
 
     @property
     def air_pressure(self) -> Optional[float]:
