@@ -4,8 +4,8 @@ Implementation of Basic KNX 2-Byte Signed Values.
 They correspond the following KNX DPTs:
     8.*** 2-byte/octet signed (2's complement), i.e. percentV16, delta time
 """
-
 import struct
+from typing import Optional, Tuple
 
 from xknx.exceptions import ConversionError
 
@@ -22,26 +22,26 @@ class DPT2ByteSigned(DPTBase):
     value_min = -32768
     value_max = 32767
     dpt_main_number = 8
-    dpt_sub_number = None
+    dpt_sub_number: Optional[int] = None
     value_type = "2byte_signed"
     unit = ""
-    resolution = 1
+    resolution: float = 1
     payload_length = 2
 
     _struct_format = ">h"
 
     @classmethod
-    def from_knx(cls, raw):
+    def from_knx(cls, raw: Tuple[int, ...]) -> int:
         """Parse/deserialize from KNX/IP raw data."""
         cls.test_bytesarray(raw)
 
         try:
-            return struct.unpack(cls._struct_format, bytes(raw))[0]
+            return struct.unpack(cls._struct_format, bytes(raw))[0]  # type: ignore
         except struct.error:
             raise ConversionError("Could not parse %s" % cls.__name__, raw=raw)
 
     @classmethod
-    def to_knx(cls, value):
+    def to_knx(cls, value: int) -> Tuple[int, ...]:
         """Serialize to KNX/IP raw data."""
         try:
             knx_value = int(value)
@@ -52,7 +52,7 @@ class DPT2ByteSigned(DPTBase):
             raise ConversionError("Could not serialize %s" % cls.__name__, value=value)
 
     @classmethod
-    def _test_boundaries(cls, value):
+    def _test_boundaries(cls, value: int) -> bool:
         """Test if value is within defined range for this object."""
         return cls.value_min <= value <= cls.value_max
 
